==> XIV_host_attach-1.1-suse-11-x64.tar.gz: opt/xiv/host_attach/lib/python/hostattachment/platform/iscsi/open_iscsi/nextra.py <==
#-------------------------------------------------------------------------------------------------
# Copyright (c) International Business Machines Corp., 2009
#
# IBM XIV Storage System Software
#
# Licensed materials provided under the terms of the IBM International Program
# License Agreement. See the Software
# licensing materials that came with the IBM XIV Storage System for terms and
# conditions.
#
#-------------------------------------------------------------------------------------------------

import logging

from execute import ExternalCommand

class Nextra(object):
    def __init__(self, query_ip):
        self.target_name = ''
        self.portals = []
        self.query_ip = query_ip

    def query(self):
        discovery = ExternalCommand('iscsiadm -m discovery -t sendtargets -p %s' % self.query_ip)
        discovery.execute()
        if not discovery.is_error_free() and not discovery.contains('already exists'):
            logging.error('failed to query %s' % self.query_ip)
            return False
        for line in discovery.output.splitlines():
            (initiator, target) = line.strip().split(' ',1)
            self.target_name = target
            self.portals.append(initiator.split(',',1)[0])
#            if line.__contains__('Target'):
#                self.target_name = line.strip().split(' ')[1]
#            elif line.__contains__('Portal'):
#                self.portals.append(line.strip().split(':')[1].strip())
        if not self.portals.__contains__(self.query_ip):
            self.portals.append(self.query_ip)
        return True

    def discover_from_all_portals(self):
        logging.info('discovering iSCSI Portals')
        for portal in self.portals:
            self.discover_through_portal(portal)

    def undiscover_from_all_portals(self):
        logging.info('undiscovering iSCSI Portals')
        for portal in self.portals:
            self.undiscover_through_portal(portal)

    def connect_to_all_portals(self):
        logging.info('connecting to all iSCSI Portals')
        for portal in self.portals:
            self.connect_to_portal(portal)

    def disconnect_from_all_portals(self):
        logging.info('disconnecting from all iSCSI Portals')
        for portal in self.portals:
            self.disconnect_from_portal(portal)

    def connect_to_portal(self, portal):
        self.set_portal_auto_login(portal)
        self.login_to_portal(portal)

    def set_portal_auto_login(self, portal):
        connect = ExternalCommand('iscsiadm -m node -p %s -T %s -o update -n node.conn[0].startup -v automatic' % (portal, self.target_name))
        connect.execute()
        if not connect.is_error_free() and not connect.contains('already exists'):
            return False
        command = ExternalCommand('iscsiadm -m node -p %s -T %s -o update -n node.startup -v automatic' % (portal, self.target_name))
        command.execute()
        if not command.is_error_free() and not command.contains('already exists'):
            return False

    def login_to_portal(self, portal):
        command = ExternalCommand('iscsiadm -m node -p %s -T %s -l' % (portal, self.target_name))
        command.execute()
        if not command.is_error_free() and not command.contains('already exists'):
            logging.error('failed to login to portal %s' % portal)
            return False
        return True

    def disconnect_from_portal(self, portal):
        self.logout_from_portal(portal)
        self.remove_connection_to_portal(portal)

    def logout_from_portal(self, portal):
        logout = ExternalCommand('iscsiadm -m node -p %s -T %s -u' % (portal, self.target_name))
        logout.execute()

    def remove_connection_to_portal(self, portal):
        delete = ExternalCommand('iscsiadm -m node -p %s -T %s -o delete' % (portal, self.target_name))
        delete.execute()

    def discover_through_portal(self, portal):
        discovery = ExternalCommand('iscsiadm -m discovery -t sendtargets -p %s' % portal)
        discovery.execute()
        if not discovery.is_error_free() and not discovery.contains('already exists'):
            logging.warn('failed to query %s' % portal)

    def undiscover_through_portal(self, portal):
        discovery = ExternalCommand('iscsiadm -m discovery -p %s -o delete' % portal)
        discovery.execute()
        if not discovery.is_error_free() and not discovery.contains('already exists'):
            logging.warn('failed to remove discovery address %s' % portal)
            return False
        return True

==> XIV_host_attach-1.1.1-suse-11-x64.tar.gz: opt/xiv/host_attach/lib/python/hostattachment/platform/iscsi/open_iscsi/nextra.py <==
#-------------------------------------------------------------------------------------------------
# Copyright (c) International Business Machines Corp., 2009
#
# IBM XIV Storage System Software
#
# Licensed materials provided under the terms of the IBM International Program
# License Agreement. See the Software
# licensing materials that came with the IBM XIV Storage System for terms and
# conditions.
#
#-------------------------------------------------------------------------------------------------

import logging

from execute import ExternalCommand
from hostattachment.platform.iscsi.classes import IscsiQueryError
from hostattachment.exceptions import HostAttachmentError

class Nextra(object):
    def __init__(self, query_ip):
        self.target_name = ''
        self.portals = []
        self.query_ip = query_ip

    def query(self):
        discovery = ExternalCommand('iscsiadm -m discovery -t sendtargets -p %s' % self.query_ip)
        discovery.execute()
        if not discovery.is_error_free() and not discovery.contains('already exists'):
            logging.error('Failed to query %s' % self.query_ip)
            raise IscsiQueryError('Failed to query %s' % self.query_ip)
        for line in discovery.output.splitlines():
            (target_ip, target_name) = line.strip().split(' ',1)
            self.target_name = target_name
            self.portals.append(target_ip.split(',',1)[0])
            if line.__contains__('Target'):
                self.target_name = line.strip().split(' ')[1]
            elif line.__contains__('Portal'):
                self.portals.append(line.strip().split(':')[1].strip())
        if not self.portals.__contains__(self.query_ip):
            self.portals.append(self.query_ip)
        return True

    def discover_from_all_portals(self):
        logging.info('discovering iSCSI Portals')
        for portal in self.portals:
            self.discover_through_portal(portal)

    def undiscover_from_all_portals(self):
        logging.info('undiscovering iSCSI Portals')
        for portal in self.portals:
            self.undiscover_through_portal(portal)

    def connect_to_all_portals(self):
        logging.info('connecting to all iSCSI Portals')
        for portal in self.portals:
            self.connect_to_portal(portal)

    def disconnect_from_all_portals(self):
        logging.info('disconnecting from all iSCSI Portals')
        for portal in self.portals:
            self.disconnect_from_portal(portal)

    def connect_to_portal(self, portal):
        self.set_portal_auto_login(portal)
        self.login_to_portal(portal)

    def set_portal_auto_login(self, portal):
        connect = ExternalCommand('iscsiadm -m node -p %s -T %s -o update -n node.conn[0].startup -v automatic' % (portal, self.target_name))
        connect.execute()
        if not connect.is_error_free() and not connect.contains('already exists'):
            return False
        command = ExternalCommand('iscsiadm -m node -p %s -T %s -o update -n node.startup -v automatic' % (portal, self.target_name))
        command.execute()
        if not command.is_error_free() and not command.contains('already exists'):
            return False

    def login_to_portal(self, portal):
        command = ExternalCommand('iscsiadm -m node -p %s -T %s -l' % (portal, self.target_name))
        command.execute()
        if not command.is_error_free() and not command.contains('already exists'):
            logging.error('Failed to login to portal %s' % portal)
            raise HostAttachmentError("Failed to login to portal %s" % (portal))
        return True

    def disconnect_from_portal(self, portal):
        self.logout_from_portal(portal)
        self.remove_connection_to_portal(portal)

    def logout_from_portal(self, portal):
        logout = ExternalCommand('iscsiadm -m node -p %s -u' % (portal))
        logout.execute()

    def remove_connection_to_portal(self, portal):
        delete = ExternalCommand('iscsiadm -m node -p %s -o delete' % (portal))
        delete.execute()

    def discover_through_portal(self, portal):
        discovery = ExternalCommand('iscsiadm -m discovery -t sendtargets -p %s' % portal)
        discovery.execute()
        if not discovery.is_error_free() and not discovery.contains('already exists'):
            logging.warn('failed to query %s' % portal)

    def undiscover_through_portal(self, portal):
        discovery = ExternalCommand('iscsiadm -m discovery -p %s -o delete' % portal)
        discovery.execute()
        if not discovery.is_error_free() and not discovery.contains('already exists'):
            logging.warn('failed to remove discovery address %s' % portal)
            return False
        return True
